@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    29-Jun-16 at 14:39:33
 ;;
-;; Copyright (C) 1992-2017  Free Software Foundation, Inc.
+;; Copyright (C) 1992-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -12,17 +12,6 @@
 ;;; Commentary:
 
 ;;; Code:
-;;; ************************************************************************
-;;; Public variables
-;;; ************************************************************************
-
-;;; Support mouse handling and Koutlines under GNU Emacs V19 or higher.
-;;;
-;;;###autoload
-(defconst hyperb:emacs-p
-  (and (not (featurep 'xemacs)) emacs-version)
-  "Version string if running under GNU Emacs, else nil")
-
 ;;; ************************************************************************
 ;;; Hyperbole Directory Setting (dynamically computed)
 ;;; ************************************************************************
@@ -33,7 +22,7 @@
 			      (locate-file "hmouse-tag.el" load-path)
 			      ""))
 			 (error
-			  "(Hyperbole): Failed to set hyperb:dir.  Try setting it manually."))
+			  "(Hyperbole): Failed to set hyperb:dir.  Try setting it manually"))
   "Directory where the Hyperbole executable code is kept.
 It must end with a directory separator character.")
 
@@ -57,8 +46,7 @@ It must end with a directory separator character.")
 (add-to-list 'load-path (expand-file-name "kotl/" hyperb:dir))
 ;; Invoke kotl-mode for files ending in ".kotl".
 ;; Also allow ".kot" for DOS and Windows users.
-(setq auto-mode-alist (cons '("\\.kotl$\\|\\.kot$" . kotl-mode)
-			    auto-mode-alist))
+(add-to-list 'auto-mode-alist '("\\.kotl?\\'" . kotl-mode))
 
 (provide 'hload-path)
 
