@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    04-Feb-90
 ;;
-;; Copyright (C) 1989-2018  Free Software Foundation, Inc.
+;; Copyright (C) 1989-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -723,7 +723,8 @@ the given direction."
 	   (_ (error "(hkey-buffer-move): Invalid movement direction, '%s'" direction))))
 	(hkey-swap-buffers w1 (selected-window)))
     ;; ... but if not available, use the Emacs builtin windmove package.
-    (require 'windmove)
+    (eval-and-compile
+      (require 'windmove))
     (windmove-do-window-select direction arg)))
 
 ;;; ************************************************************************
@@ -785,7 +786,7 @@ Return non-nil iff associated help documentation is found."
     (if (and (consp call) (eq (car call) 'call-interactively))
 	(if (consp (cadr call))
 	    (setq cmd-sym (if (memq (caadr call) '(function quote))
-			      (cadadr call) 
+			      (cadadr call)
 			    (caadr call)))))
     (setq calls (if (and (consp call) (eq (car call) 'or))
 		    (mapcar 'identity (cdr call))
@@ -841,7 +842,12 @@ Return non-nil iff associated help documentation is found."
 			  calls)
 
 		    (when (memq cmd-sym '(hui:hbut-act hui:hbut-help))
-		      (princ (format "BUTTON SPECIFICS:\n\n%s\n"
+		      (princ (format "%s BUTTON SPECIFICS:\n\n%s\n"
+				     (htype:def-symbol
+				      (if (eq (hattr:get 'hbut:current 'categ)
+					      'explicit)
+					  (hattr:get 'hbut:current 'actype)
+					(hattr:get 'hbut:current 'categ)))
 				     (actype:doc 'hbut:current t)))
 		      (hattr:report
 		       (nthcdr 2 (hattr:list 'hbut:current))))
@@ -958,7 +964,7 @@ Return t if help is displayed, nil otherwise."
 		     (hmouse-function #'hkey-assist-help assist-flag args)
 		     t)))
       (when help-shown
-	;; Then both Smart Keys have been released. 
+	;; Then both Smart Keys have been released.
 	(setq action-key-cancelled nil
 	      assist-key-cancelled nil)
 	t))))
@@ -1162,7 +1168,7 @@ the position (not below another application's window)."
 (defun hmouse-window-coordinates (&optional event)
   "Return a list (window (x-chars . y-chars)) for optional EVENT.
 Always ignores EVENT coordinates and uses current mouse position.
-The area of the EVENT is utilized. If EVENT is not given and the
+The area of the EVENT is utilized.  If EVENT is not given and the
 free variable `assist-flag' is non-nil, EVENT is set to
 `assist-key-release-args', otherwise, `action-key-release-args'.
 
@@ -1259,13 +1265,10 @@ Under InfoDock and XEmacs, `zmacs-region' must be t; under GNU Emacs,
 
 
 ;; Save any active region to `hkey-region' when the mouse is moved between frames or buffers.
-(if (featurep 'xemacs)
-    (add-hook 'mouse-leave-frame-hook #'hmouse-save-region)
-  ;; GNU Emacs
-  (add-hook 'mouse-leave-buffer-hook #'hmouse-save-region))
+(add-hook 'mouse-leave-buffer-hook #'hmouse-save-region)
 
 ;; BW - Last confirmed in 1999, for some reason, using this next
-;; function in byte-compiled form caused the first character 
+;; function in byte-compiled form caused the first character
 ;; after a mouse key depress to be dropped from the input queue when running
 ;; Emacs under X.  The non-byte-compiled form always worked fine.  We
 ;; assume this is no longer a problem in 2016 but have this note here
@@ -1277,20 +1280,11 @@ lines or if ARGS is null and there is no graphical window system,
 return current point as a marker."
   (and (car args) (listp (car args)) (setq args (car args)))
   (if (and args (hyperb:window-system))
-      (progn (hmouse-set-point-at args)
-	     (cond ((featurep 'xemacs)
-		    (if (eventp current-mouse-event)
-			(copy-event current-mouse-event)))
-		   ((equal (hyperb:window-system) "next")
-		    (let ((win (car args)))
-		      (list win
-			    (+ (nth 1 args) (nth 0 (window-edges win)))
-			    (+ (nth 2 args) (nth 1 (window-edges win))))))
-		   (t args)))
+      (progn (hmouse-set-point-at args) args)
     (list 'keyboard-drag (posn-at-point))))
 
 (defun hmouse-set-point-at (set-point-arg-list)
-  "Set point to cursor position using SET-POINT-ARG-LIST and returns t.
+  "Set point to cursor position using SET-POINT-ARG-LIST and return t.
 If 'hmouse-set-point-command' is not bound to a function, this does nothing
 and returns nil."
   (if (fboundp hmouse-set-point-command)
@@ -1330,7 +1324,7 @@ is not bound to a valid function."
       (setq action-key-release-window (hmouse-key-release-window)
 	    action-key-release-prev-point (point-marker)))
     (and (eq major-mode 'br-mode)
-	 (setq action-mouse-key-prev-window 
+	 (setq action-mouse-key-prev-window
 	       (if (br-in-view-window-p)
 		   (save-window-excursion
 		     (br-next-listing-window)
