@@ -48,7 +48,7 @@
 	 (not (stringp htz:local)))
     (progn
       ;; Comment out the following `error' line...
-      (error "(hsettings.el): Configure the TIMEZONE SETTING section in this file.")
+      (error "(hsettings.el): Configure the TIMEZONE SETTING section in this file")
       ;; ... and uncomment the following line, substituting an appropriate
       ;;     timezone from the list in the variable, `htz:world-timezones'
       ;;     in the file, "htz.el".
@@ -164,7 +164,7 @@ package to display search results."
       (user-error "(Hyperbole): Invalid web search service `%s'" service-name))))
 
 (defcustom inhibit-hyperbole-messaging t
-  "*Determines whether Hyperbole supports explicit buttons in mail and news buffers.
+  "*Determine whether Hyperbole supports explicit buttons in mail and news buffers.
 The default of t means disable such support (work remains to
 modernize these features).  When t, Hyperbole will not alter
 messaging mode hooks nor overload functions from these packages,
@@ -176,7 +176,7 @@ to your personal Emacs initialization file, prior to loading
 Hyperbole, and then restart Emacs."
   :type 'boolean
   :initialize 'custom-initialize-set
-  :set (lambda (symbol value) 
+  :set (lambda (symbol value)
 	 ;; Invert value to produce ARG for hyperbole-toggle-messaging.
 	 (hyperbole-toggle-messaging (if value 0 1)))
   :group 'hyperbole-buttons)
@@ -223,7 +223,7 @@ obtained search string."
 ;; No-op unless set by one of the conditionals below.
 (defun hui:but-flash ())
 
-(cond ((and hyperb:emacs-p (not noninteractive))
+(cond ((not noninteractive)
        (require 'hui-em-but)
        ;; Highlight explicit buttons whenever a file is read in.
        (add-hook 'find-file-hook #'hproperty:but-create t)
@@ -243,29 +243,6 @@ obtained search string."
        ;;
        ;; If you find that the Hyperbole button flash time is too slow
        ;; or too fast, adjust it here.
-       (setq hproperty:but-flash-time 1000))
-
-      ((and (featurep 'xemacs) (not noninteractive))
-       (require 'hui-xe-but)
-       ;;
-       ;; Highlight explicit buttons when files are read in.
-       (add-hook 'find-file-hook #'hproperty:but-create t)
-       (defalias 'hui:but-flash 'hproperty:but-flash)
-       ;;
-       ;; Substitute for the nil argument below a valid X color name with
-       ;; which to highlight buttons if the default highlighting does not
-       ;; appeal to you. See "hui-xe-but.el" for how this works.
-       (hproperty:cycle-but-color nil)
-       ;;
-       ;; Non-nil means highlight all explict buttons with `hproperty:but-face'.
-       (setq hproperty:but-highlight-flag t)
-       ;;
-       ;; Non-nil means visually emphasize that button under mouse cursor is
-       ;; selectable.
-       (setq hproperty:but-emphasize-p nil)
-       ;;
-       ;; If you find that the Hyperbole button flash time is too slow
-       ;; or too fast, adjust it here.
        (setq hproperty:but-flash-time 1000)))
 
 ;;; ************************************************************************
