@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    21-Aug-92
 ;;
-;; Copyright (C) 1992-2016  Free Software Foundation, Inc.
+;; Copyright (C) 1992-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -16,8 +16,9 @@
 
 ;;; Code:
 
-(unless (and hyperb:emacs-p (not noninteractive))
-  (error "(hui-em-but.el): Load only when running GNU Emacs interactively."))
+(when noninteractive
+  ;; FIXME: Loading a file should always be harmless!
+  (error "(hui-em-but.el): Load only when running GNU Emacs interactively"))
 
 ;;; ************************************************************************
 ;;; Other required Elisp libraries
@@ -27,7 +28,7 @@
 (require 'hbut)
 
 (defun hproperty:background ()
-  "Returns default background color for current frame."
+  "Return default background color for current frame."
   (or (face-background (defface default nil
 			 "Standard text face."
 			 :group 'hyperbole-buttons))
@@ -35,7 +36,7 @@
       "White"))
 
 (defun hproperty:foreground ()
-  "Returns default foreground color for current frame."
+  "Return default foreground color for current frame."
   (or (face-foreground (defface default nil
 			 "Standard text face."
 			 :group 'hyperbole-buttons))
@@ -124,7 +125,7 @@ expression which matches an entire button string.
 If REGEXP-MATCH is non-nil, only buttons matching this argument are
 highlighted."
   (when hproperty:but-highlight-flag
-    (ebut:map (lambda (lbl start end)
+    (hbut:map (lambda (lbl start end)
 		(hproperty:but-add start end hproperty:but-face))
 	      start-delim end-delim regexp-match 'include-delims)))
 
@@ -308,7 +309,7 @@ highlighted."
 ;;; ************************************************************************
 
 (defun hproperty:cycle-but-color (&optional color)
-  "Switches button color to optional COLOR name or next item referenced by hproperty:color-ptr."
+  "Switch button color to optional COLOR name or next item referenced by hproperty:color-ptr."
   (interactive "sHyperbole button color: ")
   (if (not (display-color-p))
       nil
@@ -364,7 +365,7 @@ highlighted."
   (make-local-variable 'hproperty:item-face)
   (if (stringp background) (setq hproperty:item-highlight-color background))
   (if (not hproperty:highlight-face)
-      (progn 
+      (progn
 	(setq hproperty:highlight-face
 	      (defface hproperty:highlight-face nil
   "Item highlighting face.  Use (hproperty:set-item-highlight) to set."
