@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    15-Oct-91 at 20:13:17
 ;;
-;; Copyright (C) 1991-2017  Free Software Foundation, Inc.
+;; Copyright (C) 1991-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -17,6 +17,7 @@
 ;;; ************************************************************************
 
 (require 'hypb)
+(require 'hsettings)                    ;For hyperbole-web-search-alist
 (require 'browse-url)
 
 ;;; ************************************************************************
@@ -76,7 +77,7 @@ documentation, not the full text."
       (setq hui:menu-p nil))))
 
 (defun hui:menu-act (menu &optional menu-list doc-flag help-string-flag)
-  "Prompts user with Hyperbole MENU (a symbol) and performs selected item.
+  "Prompt user with Hyperbole MENU (a symbol) and perform selected item.
 Optional second argument MENU-LIST is a Hyperbole menu list structure from
 which to extract MENU.  It defaults to `hui:menus'.  See its definition for
 the menu list structure.
@@ -131,7 +132,7 @@ documentation, not the full text."
     (hui:menu-backward-item)))
 
 (defun hui:menu-doc (key-sequence &optional help-string-flag)
-  "Returns formatted documentation for a normalized Hyperbole minibuffer menu KEY-SEQUENCE.
+  "Return formatted documentation for a normalized Hyperbole minibuffer menu KEY-SEQUENCE.
 With optional HELP-STRING-FLAG, instead returns the one line help string for the key sequence."
   (when (and (stringp key-sequence)
 	     (not (eq key-sequence ""))
@@ -146,16 +147,12 @@ With optional HELP-STRING-FLAG, instead returns the one line help string for the
 	(discard-input)))))
 
 (defun hui:menu-enter (&optional char-str)
-  "Uses CHAR-STR or last input character as minibuffer argument."
+  "Use CHAR-STR or last input character as minibuffer argument."
   (interactive)
   (let ((input (or char-str (aref (recent-keys) (1- (length (recent-keys)))))))
-    (cond (hyperb:emacs-p
-	   (and (not (integerp input))
-		(eventp input)
-		(setq input (event-basic-type input))))
-	  ((featurep 'xemacs)
-	   (if (eventp input)
-	       (setq input (event-to-character input)))))
+    (and (not (integerp input))
+	 (eventp input)
+	 (setq input (event-basic-type input)))
     (if (or (symbolp input)
 	    (and (integerp input) (= input ?\r)))
 	(setq input (hargs:at-p)))
@@ -202,24 +199,6 @@ With optional HELP-STRING-FLAG, instead returns the one line help string for the
       (if (eq owind (minibuffer-window))
 	  (select-window owind)))))
 
-(defun hui:menu-xemacs (&optional menu menu-list)
-  "Returns an XEmacs menu built from a Hyperbole minibuffer menu.
-Optional MENU (a symbol) specifies a specific submenu of optional MENU-LIST.
-a Hyperbole menu list structure.  Otherwise, all menus are used.
-MENU defaults to 'hyperbole and MENU-LIST to `hui:menus'.  See `hui:menus'
-definition for the format of the menu list structure."
-  (mapcar
-   (lambda (entry)
-     (or (consp entry)
-	 (error "(hui:menu-xemacs): Invalid menu entry: %s" entry))
-     (let ((label (car entry))
-	   (content (car (cdr entry))))
-       (cond ((null content) (hypb:replace-match-string ">$" label "" t))
-	     ((and (consp content) (eq (car content) 'menu))
-	      (hui:menu-xemacs (cdr content)))
-	     (t (vector label content 't)))))
-   (cdr (assq (or menu 'hyperbole) (or menu-list hui:menus)))))
-
 (defun hui:menu-select (menu-alist &optional doc-flag help-string-flag)
   "Prompts user to choose the first character of any item from MENU-ALIST.
 Case is not significant.  If chosen by direct selection with the Assist Key,
@@ -294,7 +273,7 @@ documentation, not the full text."
       (nth (- (length winds) (length (memq bot bot-list))) winds))))
 
 (defun hui:menu-item (key doc-flag help-string-flag &optional menu menu-alist)
-"Returns either the action or the documentation for a Hyperbole minibuffer menu item KEY.
+"Return either the action or the documentation for a Hyperbole minibuffer menu item KEY.
 If DOC-FLAG is non-nil, returns the fully formatted documentation unless
 HELP-STRING-FLAG is non-nil, in which case only the first line of
 documentation is returned.  If both are nil, the action form for the
@@ -302,7 +281,7 @@ item is returned.
 
 Two additional optional arguments determine the items from which key
 selects, MENU and MENU-ALIST are Hyperbole minibuffer menu internal
-constructs.  If not given, the top-level Hyperbole menu is used."
+constructs.  If not given, the top level Hyperbole menu is used."
   (unless menu-alist
     (setq menu-alist (or (cdr (assq (or (and (symbolp menu) menu) 'hyperbole)
 				    hui:menus))
@@ -334,7 +313,7 @@ constructs.  If not given, the top-level Hyperbole menu is used."
 	    act-form)))))
 
 (defun hui:menu-line (menu-alist)
-  "Returns a menu line string built from MENU-ALIST."
+  "Return a menu line string built from MENU-ALIST."
   (let ((menu-prompt (concat (car (car menu-alist)) "  "))
 	(menu-items (mapconcat 'car (cdr menu-alist) "  "))
 	menu-line)
@@ -384,10 +363,6 @@ constructs.  If not given, the top-level Hyperbole menu is used."
   (define-key hui:menu-mode-map [backtab]       #'hui:menu-backward-item) ;; Shift-TAB
   (define-key hui:menu-mode-map "\M-\C-i"       #'hui:menu-backward-item) ;; M-TAB
   ;;
-  ;; This next binding is necessary since the default button1 binding under
-  ;; XEmacs, mouse-track, is broken under XEmacs V19.8.
-  (and (featurep 'xemacs) window-system
-       (define-key hui:menu-mode-map 'button1 'mouse-set-point))
   (let ((i 32))
     (while (<= i 126)
       (define-key hui:menu-mode-map (char-to-string i) 'hui:menu-enter)
@@ -398,7 +373,7 @@ constructs.  If not given, the top-level Hyperbole menu is used."
 ;;; ************************************************************************
 
 (defun hyperbole-minibuffer-menu ()
-  "Rebuilds and returns the entire Hyperbole minibuffer menu structure."
+  "Rebuild and return the entire Hyperbole minibuffer menu structure."
 (setq
  hui:menus
  (delq nil
@@ -552,8 +527,8 @@ constructs.  If not given, the top-level Hyperbole menu is used."
 	 ))
        '(ebut .
 	 (("EButton>")
-	  ("Act"    hui:hbut-act
-	    "Activates button at point or prompts for explicit button.")
+	  ("Act"    hui:ebut-act
+	    "Activates explicit button at point or prompts for explicit button to activate.")
 	  ("Create" hui:ebut-create)
 	  ("Delete" hui:ebut-delete)
 	  ("Edit"   hui:ebut-modify "Modifies any desired button attributes.")
@@ -596,6 +571,7 @@ constructs.  If not given, the top-level Hyperbole menu is used."
 	  ("Info"   (id-info "(hyperbole)Global Buttons")
 	   "Displays manual section on global buttons.")
 	  ("Modify" hui:gbut-modify "Modifies global button attributes.")
+	  ("Rename" hui:gbut-rename "Renames a global button.")
 	  ))
        '(ibut .
 	 (("IButton>")
@@ -605,6 +581,10 @@ constructs.  If not given, the top-level Hyperbole menu is used."
 	  ("Help"   hui:hbut-help   "Reports on button's attributes.")
 	  ("Info"   (id-info "(hyperbole)Implicit Buttons")
 	   "Displays manual section on implicit buttons.")
+	  ("Label"  hui:ibut-label-create
+	   "Creates an implicit button label preceding an existing implicit button at point, if any.")
+	  ("Rename" hui:ibut-rename
+	   "Modifies a label preceding an implicit button in the current buffer.")
 	  ("Types"  (hui:htype-help 'ibtypes 'no-sort)
 	   "Displays documentation for one or all implicit button types.")
 	  ))
