@@ -65,8 +65,27 @@
 	       (message "{%s} now runs `%s'; prior {%s} binding removed" new-key-text cmd old-key-text))
       (message "{%s} now runs `%s'" new-key-text cmd))))
 
+(defun hui:ebut-act (&optional but)
+  "Executes action for optional explicit button symbol BUT in current buffer.
+Default is the current button."
+  (interactive
+   (let ((but (ebut:at-p)) (lst))
+     (list
+      (cond (but)
+	    ((setq lst (ebut:alist))
+	     (ebut:get (ebut:label-to-key
+			(hargs:read-match "Button to execute: " lst nil t
+					  (ebut:label-p 'as-label) 'ebut))))
+	    (t (hypb:error "(ebut-act): No explicit buttons in buffer."))))))
+  (cond ((and (called-interactively-p 'interactive) (null but))
+	 (hypb:error "(ebut-act): No current explicit button to activate."))
+	((not (hbut:is-p but))
+	 (hypb:error "(ebut-act): Explicit button is invalid; it has no attributes."))
+	(t (or but (setq but 'hbut:current))
+	   (hui:but-flash) (hbut:act but))))
+
 (defun hui:ebut-create (&optional start end)
-  "Creates an explicit but starting from label between optional START and END.
+  "Create an explicit Hyperbole button starting from label between optional START and END.
 Indicates by delimiting and adding any necessary instance number of the button
 label."
   (interactive (list (and (marker-position (hypb:mark-marker t))
@@ -79,10 +98,10 @@ label."
 	    (hui:hbut-label-default start end (not (called-interactively-p 'interactive)))
 	    lbl (hui:hbut-label default-lbl "ebut-create"))
       (if (not (equal lbl default-lbl)) (setq default-lbl nil))
-      
+
       (setq but-buf (if default-lbl (current-buffer) (hui:ebut-buf)))
       (hui:buf-writable-err but-buf "ebut-create")
-      
+
       (hattr:set 'hbut:current 'loc (hui:key-src but-buf))
       (hattr:set 'hbut:current 'dir (hui:key-dir but-buf))
       (setq actype (hui:actype))
@@ -106,10 +125,10 @@ Signals an error if point is not within a button."
 		       nil)))
   (cond ((null but-key)
 	 (hypb:error
-	  "(ebut-delete): Point is not over the label of an existing button."))
+	  "(ebut-delete): Point is not over the label of an existing button"))
 	((not (stringp but-key))
 	 (hypb:error
-	  "(ebut-delete): Invalid label key argument: '%s'." but-key)))
+	  "(ebut-delete): Invalid label key argument: '%s'" but-key)))
   (let ((interactive (called-interactively-p 'interactive)))
     (if (and hui:ebut-delete-confirm-p interactive)
 	(if (y-or-n-p (format "Delete button %s%s%s? "
@@ -118,9 +137,9 @@ Signals an error if point is not within a button."
 	    (hui:ebut-delete-op interactive but-key key-src)
 	  (message ""))
       (hui:ebut-delete-op interactive but-key key-src))))
-      
+
 (defun hui:ebut-edit ()
-  "Creates or modifies an explicit Hyperbole button when conditions are met.
+  "Create or modifies an explicit Hyperbole button when conditions are met.
 A region must have been delimited with the action-key and point must now be
 within it before this function is called or it will do nothing.  The region
 must be no larger than the size given by 'ebut:max-len'.  It must be entirely
@@ -153,13 +172,13 @@ Signals an error when no such button is found in the current buffer."
 	(but-buf (current-buffer))
 	actype but new-lbl)
     (save-excursion
-      (or (called-interactively-p 'interactive)
-	  (hui:buf-writable-err but-buf "ebut-modify"))
-      
-      (or (setq but (ebut:get lbl-key but-buf))
-	  (progn (pop-to-buffer but-buf)
-		 (hypb:error "(ebut-modify): Invalid button, no data for '%s'." lbl)))
-      
+      (unless (called-interactively-p 'interactive)
+	(hui:buf-writable-err but-buf "ebut-modify"))
+
+      (unless (setq but (ebut:get lbl-key but-buf))
+	(pop-to-buffer but-buf)
+	(hypb:error "(ebut-modify): Invalid button, no data for '%s'" lbl))
+
       (setq new-lbl
 	    (hargs:read
 	     "Change button label to: "
@@ -169,7 +188,7 @@ Signals an error when no such button is found in the current buffer."
 	     (format "(ebut-modify): Enter a string of at most %s chars."
 		     ebut:max-len)
 	     'string))
-      
+
       (hattr:set 'hbut:current 'loc (hui:key-src but-buf))
       (hattr:set 'hbut:current 'dir (hui:key-dir but-buf))
       (setq actype (hui:actype (hattr:get but 'actype)))
@@ -198,11 +217,11 @@ Signals an error if any problem occurs."
 	   (setq curr-label hui:ebut-label-prev
 		 new-label (ebut:label-p 'as-label))
 	 (setq new-label nil
-	       curr-label 
+	       curr-label
 	       (or (ebut:label-p 'as-label)
 		   (let ((buts (ebut:alist)))
 		     (if (null buts)
-			 (hypb:error "(ebut-rename): No explicit buttons in buffer.")
+			 (hypb:error "(ebut-rename): No explicit buttons in buffer")
 		       (prog1 (hargs:read-match
 			       "Button label to rename: "
 			       buts nil t nil 'ebut)
@@ -229,7 +248,7 @@ Signals an error if any problem occurs."
 	   (hypb:error "(ebut-rename): 'new-label' must be a non-empty string: %s"
 		       new-label)))
     (or (ebut:get (ebut:label-to-key curr-label))
-	(hypb:error "(ebut-rename): Can't rename %s since no button data."
+	(hypb:error "(ebut-rename): Can't rename %s since no button data"
 	       curr-label)))
   (cond (new-label
 	 (ebut:operate curr-label new-label)
@@ -238,10 +257,10 @@ Signals an error if any problem occurs."
 	(curr-label
 	 (setq hui:ebut-label-prev curr-label)
 	 (message "Edit button label and use same command to finish rename."))
-	(t (hypb:error "(ebut-rename): Move point to within a button label."))))
+	(t (hypb:error "(ebut-rename): Move point to within a button label"))))
 
 (defun hui:ebut-search (string &optional match-part)
-  "Shows lines of files/buffers containing an explicit but match for STRING.
+  "Show lines of files/buffers containing an explicit but match for STRING.
 Returns number of buttons matched and displayed.
 By default, only matches for whole button labels are found, optional MATCH-PART
 enables partial matches.  The match lines are shown in a buffer which serves as
@@ -249,7 +268,7 @@ a menu to find any of the occurrences."
   (interactive (list (read-string "Search for button string: ")
 		     (y-or-n-p "Enable partial matches? ")))
   (if (not (stringp string))
-      (hypb:error "(ebut-search): String to search for is required."))
+      (hypb:error "(ebut-search): String to search for is required"))
   (let*  ((prefix (if (> (length string) 14)
 		      (substring string 0 13) string))
 	  (out-buf (get-buffer-create (concat "*" prefix " Hypb Search*")))
@@ -275,21 +294,28 @@ a menu to find any of the occurrences."
 	total))))
 
 (defun hui:error (&rest args)
-  (hypb:error "(hui:error): Obsolete, use hypb:error instead."))
+  (hypb:error "(hui:error): Obsolete, use hypb:error instead"))
 
 (defun hui:gbut-create (lbl)
-  "Creates Hyperbole global button with LBL."
-  (interactive "sCreate global button labeled: ")
-  (let (but-buf actype)
+  "Create Hyperbole explicit global button with LBL.
+
+To create an implicit global button, add the text for an implicit
+button to `gbut:file` and then with point on the implicit button,
+invoke: {C-h h i l}, to label/name it."
+  (interactive "sCreate explicit global button labeled: ")
+  (let (but-buf actype src-dir)
     (save-excursion
-      (setq actype (hui:actype))
-      (setq but-buf (set-buffer (find-file-noselect gbut:file)))
+      (setq src-dir default-directory
+	    actype (hui:actype)
+	    but-buf (set-buffer (find-file-noselect gbut:file)))
       (hui:buf-writable-err but-buf "ebut-create")
       ;; This prevents movement of point which might be useful to user.
       (save-excursion
 	(goto-char (point-max))
+	;; loc = Directory of the global button file
 	(hattr:set 'hbut:current 'loc (hui:key-src but-buf))
-	(hattr:set 'hbut:current 'dir (hui:key-dir but-buf))
+	;; dir = default-directory of current buffer when button is created
+	(hattr:set 'hbut:current 'dir src-dir)
 	(hattr:set 'hbut:current 'actype actype)
 	(hattr:set 'hbut:current 'args (hargs:actype-get actype))
 	(hattr:set 'hbut:current 'action
@@ -304,26 +330,27 @@ a menu to find any of the occurrences."
 
 (defun hui:gbut-modify (lbl-key)
   "Modifies a global Hyperbole button given by LBL-KEY.
+The button may be explicit or a labeled implicit button.
 Signals an error when no such button is found."
   (interactive (list (save-excursion
 		       (hui:buf-writable-err
 			(find-file-noselect gbut:file) "gbut-modify")
 		       (hbut:label-to-key
 			(hargs:read-match "Global button to modify: "
-					  (mapcar 'list (gbut:label-list))
-					  nil t nil 'ebut)))))
+					  (mapcar #'list (gbut:label-list))
+					  nil t nil 'gbut)))))
   (let ((lbl (hbut:key-to-label lbl-key))
+	(src-dir default-directory)
 	(but-buf (find-file-noselect gbut:file))
 	actype but new-lbl)
     (save-excursion
-      (or (called-interactively-p 'interactive)
-	  (hui:buf-writable-err but-buf "gbut-modify"))
-      
-      (or (setq but (ebut:get lbl-key but-buf))
-	  (progn (pop-to-buffer but-buf)
-		 (hypb:error
-		  "(gbut-modify): Invalid button, no data for '%s'." lbl)))
-      
+      (unless (called-interactively-p 'interactive)
+	(hui:buf-writable-err but-buf "gbut-modify"))
+
+      (unless (setq but (gbut:get lbl-key))
+	(pop-to-buffer but-buf)
+	(hypb:error "(gbut-modify): Invalid button, no data for '%s'" lbl))
+
       (setq new-lbl
 	    (hargs:read
 	     "Change global button label to: "
@@ -333,79 +360,87 @@ Signals an error when no such button is found."
 	     (format "(gbut-modify): Enter a string of at most %s chars."
 		     ebut:max-len)
 	     'string))
-      
-      (hattr:set 'hbut:current 'loc (hui:key-src but-buf))
-      (hattr:set 'hbut:current 'dir (hui:key-dir but-buf))
-      (setq actype (hui:actype (hattr:get but 'actype)))
-      (hattr:set 'hbut:current 'actype actype)
-      (hattr:set 'hbut:current 'args (hargs:actype-get actype 'modifying))
-      (hattr:set 'hbut:current 'action
-		 (and hui:ebut-prompt-for-action (hui:action actype)))
-      (set-buffer but-buf)
-      (ebut:operate lbl new-lbl))))
+
+      (if (eq (hattr:get but 'categ) 'explicit)
+	  (progn
+	    ;; Explicit buttons
+	    (hattr:set 'hbut:current 'loc (hui:key-src but-buf))
+	    (hattr:set 'hbut:current 'dir src-dir)
+	    (setq actype (hui:actype (hattr:get but 'actype)))
+	    (hattr:set 'hbut:current 'actype actype)
+	    (hattr:set 'hbut:current 'args (hargs:actype-get actype 'modifying))
+	    (hattr:set 'hbut:current 'action
+		       (and hui:ebut-prompt-for-action (hui:action actype)))
+	    (set-buffer but-buf)
+	    (ebut:operate lbl new-lbl))
+	;; Implicit buttons
+	(save-excursion
+	  (set-buffer but-buf)
+	  (ibut:rename lbl new-lbl)
+	  (when (and (called-interactively-p 'interactive)
+		     (ibut:at-p))
+	    (hui:ibut-message t)))))))
+
+(defun hui:gbut-rename (label)
+  "Interactively rename a Hyperbole global button with LABEL.
+When in the global button buffer, the default is the button at point."
+  (interactive (list (save-excursion
+		       (hui:buf-writable-err
+			(find-file-noselect gbut:file) "gbut-rename")
+		       (hbut:label-to-key
+			(hargs:read-match "Global button to rename: "
+					  (mapcar #'list (gbut:label-list))
+					  nil t nil 'gbut)))))
+  (hbut:rename (gbut:to label)))
 
 (defun hui:hbut-act (&optional but)
-  "Executes action for optional Hyperbole button symbol BUT in current buffer.
-Default is the current button."
-  (interactive
-   (let ((but (hbut:at-p)) (lst))
-     (list
-      (cond (but)
-	    ((setq lst (ebut:alist))
-	     (ebut:get (ebut:label-to-key
-			(hargs:read-match "Button to execute: " lst nil t
-					  (ebut:label-p 'as-label) 'ebut))))
-	    (t (hypb:error "(hbut-act): No explicit buttons in buffer."))))))
-  (cond ((and (called-interactively-p 'interactive) (null but))
-	 (hypb:error "(hbut-act): No current button to activate."))
-	((not (hbut:is-p but))
-	 (hypb:error "(hbut-act): Button is invalid; it has no attributes."))
-	(t (or but (setq but 'hbut:current))
-	   (hui:but-flash) (hbut:act but))))
+  "Execute action for optional Hyperbole button symbol BUT in current buffer.
+The default is the current button."
+  (hui:hbut-operate #'hbut:act "execute" but))
 
 (defun hui:hbut-current-act ()
   "Activate Hyperbole button at point or signal an error if there is no such button."
   (interactive)
   (let ((but (hbut:at-p)))
     (cond ((null but)
-	   (hypb:error "(hbut-act): No current button to activate."))
+	   (hypb:error "(hbut-act): No current button to activate"))
 	  ((not (hbut:is-p but))
-	   (hypb:error "(hbut-act): Button is invalid; it has no attributes."))
+	   (hypb:error "(hbut-act): Button is invalid; it has no attributes"))
 	  (t (hui:but-flash) (hbut:act but)))))
 
 (defun hui:hbut-help (&optional but)
-  "Checks for and explains an optional button given by symbol, BUT.
+  "Check for and explain an optional button given by symbol, BUT.
 BUT defaults to the button whose label point is within."
   (interactive)
   (setq but (or but (hbut:at-p)
 		(ebut:get (ebut:label-to-key
 			   (hargs:read-match "Help for button: "
 					     (ebut:alist) nil t nil 'ebut)))))
-  (or but
-      (hypb:error "(hbut-help):  Move point to a valid Hyperbole button."))
-  (if (not (hbut:is-p but))
-      (cond (but (hypb:error "(hbut-help): Invalid button."))
-	    (t   (hypb:error
-		  "(hbut-help): Not on an implicit button and no buffer explicit buttons."))))
+  (unless but
+    (hypb:error "(hbut-help):  Move point to a valid Hyperbole button"))
+  (unless (hbut:is-p but)
+    (cond (but (hypb:error "(hbut-help): Invalid button"))
+	  (t   (hypb:error
+		"(hbut-help): Not on an implicit button and no buffer explicit buttons"))))
   (let ((type-help-func (intern-soft
-			 (concat 
+			 (concat
 			  (htype:names 'ibtypes (hattr:get but 'categ))
 			  ":help"))))
-    (or (equal (hypb:indirect-function 'hui:but-flash)
-	       (lambda nil))
-	;; Only flash button if point is on it.
-	(let ((lbl-key (hattr:get but 'lbl-key)))
-	  (and lbl-key
-	       (or (equal lbl-key (ebut:label-p))
-		   (equal lbl-key (ibut:label-p)))
-	       (hui:but-flash))))
+    (unless (equal (hypb:indirect-function 'hui:but-flash)
+		   (lambda nil))
+      ;; Only flash button if point is on it.
+      (let ((lbl-key (hattr:get but 'lbl-key)))
+	(and lbl-key
+	     (or (equal lbl-key (ebut:label-p))
+		 (equal lbl-key (ibut:label-p)))
+	     (hui:but-flash))))
     (if (functionp type-help-func)
 	(funcall type-help-func but)
       (let ((total (hbut:report but)))
-	(if total (hui:help-ebut-highlight))))))
+	(when total (hui:help-ebut-highlight))))))
 
 (defun hui:hbut-label (default-label func-name)
-  "Reads button label from user using DEFAULT-LABEL and caller's FUNC-NAME."
+  "Read button label from user using DEFAULT-LABEL and caller's FUNC-NAME."
   (hargs:read "Button label: "
 	      (lambda (lbl)
 		(and (not (string= lbl "")) (<= (length lbl) ebut:max-len)))
@@ -415,20 +450,49 @@ BUT defaults to the button whose label point is within."
 	      'string))
 
 (defun hui:hbut-label-default (start end &optional skip-len-test)
-  "Returns default label based on START and END region markers or points.
+  "Return default label based on START and END region markers or points.
 Optional SKIP-LEN-TEST means don't limit label to `ebut:max-len' length.
-Returns nil if START or END are invalid or if region fails length test. 
+Returns nil if START or END are invalid or if region fails length test.
 
 Also has side effect of moving point to start of default label, if any."
   (if (markerp start) (setq start (marker-position start)))
   (if (markerp end) (setq end (marker-position end)))
   ;; Test whether to use region as default button label.
-  (if (and (integerp start) (integerp end) 
+  (if (and (integerp start) (integerp end)
 	   (or skip-len-test
 	       (<= (max (- end start) (- start end)) ebut:max-len)))
       (progn (goto-char start)
 	     (buffer-substring start end))))
 
+(defun hui:hbut-operate (operation operation-str &optional but)
+  "Execute OPERATION (a function) described by OPERATION-STR action on a Hyperbole button.
+Either the button at point is used or if none, then one is prompted
+for with completion of all labeled buttons within the current buffer."
+  (unless (or but (setq but (hbut:at-p)))
+    (let (lst)
+      (cond ((setq lst (nconc (ebut:alist) (ibut:alist)))
+	         (setq but (hbut:get (hbut:label-to-key
+			                      (hargs:read-match (format "Button to %s: " operation-str)
+                                                    lst nil t
+					                                (hbut:label-p 'as-label) 'hbut)))))
+	        (t (hypb:error "(hbut-operate): No labeled buttons in buffer")))))
+  (cond ((and (called-interactively-p 'interactive) (null but))
+	     (hypb:error "(hbut-operate): No current button to operate upon"))
+	    ((not (hbut:is-p but))
+	     (hypb:error "(hbut-operate): Button is invalid; it has no attributes"))
+	    (t (or but (setq but 'hbut:current))
+	       (hui:but-flash) (funcall operation but))))
+
+(defun hui:hbut-rename ()
+  "Interactively rename a Hyperbole button from the current buffer.
+The default is the button at point."
+  (cond ((ebut:at-p)
+         (call-interactively #'hui:ebut-rename))
+        ((ibut:at-p)
+         (call-interactively #'hui:ibut-rename))
+        (t
+         (hui:hbut-operate #'hbut:rename "rename"))))
+
 (defun hui:hbut-report (&optional arg)
   "Pretty prints attributes of current button, using optional prefix ARG.
 See 'hbut:report'."
@@ -436,14 +500,81 @@ See 'hbut:report'."
   (if (and arg (symbolp arg))
       (hui:hbut-help arg)
     (let ((total (hbut:report arg)))
-      (if total
-	  (progn (hui:help-ebut-highlight)
-		 (message "%d button%s." total (if (/= total 1) "s" "")))))))
+      (when total
+	(hui:help-ebut-highlight)
+	(message "%d button%s." total (if (/= total 1) "s" ""))))))
 
 (defalias 'hui:hbut-summarize 'hui:hbut-report)
 
+(defun hui:ibut-label-create ()
+  "Creates an implicit button label preceding an existing implicit button at point, if any.
+Adds the label and delimiters around it plus any necessary label instance number.
+Signals an error if point is not on an implicit button or if the button already has a label.
+
+If the implicit button type does not specify the starting locations of
+its buttons, the the label is simply inserted at point."
+  (interactive)
+  (hui:buf-writable-err (current-buffer) "ibut-label-create")
+  (let* ((ibut (ibut:at-p))
+	 (ibut-start (when ibut (hattr:get 'hbut:current 'lbl-start)))
+	 ;; non-nil when point is within an existing ibut label
+	 (label-key-start-end (when ibut (ibut:label-p nil nil nil t t)))
+	 lbl actype)
+    (cond (label-key-start-end
+	   (error "(hui:ibut-label-create): ibutton at point already has a label; try hui:ibut-rename"))
+	  (ibut
+	   (save-excursion
+	     (when ibut-start
+	       (goto-char ibut-start))
+	     (save-excursion
+	       ;; Check if ibut has an existing preceding label
+	       (skip-chars-backward "][:=<>a-zA-Z0-9#@!$%^&* -")
+	       (skip-chars-forward " ")
+	       (when (looking-at (concat (regexp-quote ibut:label-start) "\\s-*[:=a-zA-Z0-9#@!$%^&* -]+" (regexp-quote ibut:label-end)))
+		 (error "(hui:ibut-label-create): ibutton at point already has a label; try hui:ibut-rename")))
+	     (setq lbl (hui:hbut-label nil "ibut-label-create")) ; prompts for label
+	     ;; !! Handle adding instance to label
+	     (insert ibut:label-start lbl ibut:label-end ibut:label-separator))
+	   (when (called-interactively-p 'interactive)
+	     (hui:ibut-message nil)))
+	  (t (error "(hui:ibut-label-create): To add a label, point must be within the text of an implicit button")))))
+
+(defun hui:ibut-rename (lbl-key)
+  "Renames a label preceding a Hyperbole implicit button in the current buffer given by LBL-KEY.
+Signals an error when no such button is found in the current buffer."
+  (interactive (list (save-excursion
+		       (hui:buf-writable-err (current-buffer) "ibut-rename")
+		       (or (ibut:label-p)
+			   (ibut:label-to-key
+			    (hargs:read-match "Labeled implicit button to rename: "
+					      (ibut:alist) nil t nil 'ibut))))))
+  (let ((lbl (ibut:key-to-label lbl-key))
+	(but-buf (current-buffer))
+	actype but new-lbl)
+    (unless (called-interactively-p 'interactive)
+      (hui:buf-writable-err but-buf "ibut-rename"))
+
+    (unless (setq but (ibut:get lbl-key but-buf))
+      (hypb:error "(ibut-rename): Invalid button: '%s'." lbl))
+
+    (setq new-lbl
+	  (hargs:read
+	   "Change implicit button label to: "
+	   (lambda (lbl)
+	     (and (not (string= lbl "")) (<= (length lbl) ebut:max-len)))
+	   lbl
+	   (format "(ibut-rename): Enter a string of at most %s chars."
+		   ebut:max-len)
+	   'string))
+
+    (save-excursion
+      (ibut:rename lbl new-lbl)
+      (when (and (called-interactively-p 'interactive)
+		 (ibut:at-p))
+	(hui:ibut-message t)))))
+
 (defun hui:link-directly ()
-  "Creates a Hyperbole link button at depress point, linked to release point.
+  "Create a Hyperbole link button at depress point, linked to release point.
 See also documentation for `hui:link-possible-types'."
   (let* ((link-types (hui:link-possible-types))
 	 (but-window action-key-depress-window)
@@ -471,7 +602,7 @@ See also documentation for `hui:link-possible-types'."
     (select-window release-window)
 
     (cond ((= num-types 0)
-	   (error "(link-directly): No possible link type to create."))
+	   (error "(link-directly): No possible link type to create"))
 	  ((= num-types 1)
 	   (setq type-and-args (hui:list-remove-text-properties (car link-types)))
 	   (hui:link-create but-modify but-window lbl-key but-loc but-dir type-and-args))
@@ -484,7 +615,7 @@ See also documentation for `hui:link-possible-types'."
 			   (mapcar
 			    (lambda (type-and-args)
 			      (setq type (car type-and-args))
-			      (list 
+			      (list
 			       (capitalize
 				(if (string-match
 				     "^\\(link-to\\|eval\\)-"
@@ -493,9 +624,7 @@ See also documentation for `hui:link-possible-types'."
 						item (match-end 0)))
 				  item))
 			       type-and-args
-			       (documentation
-				(intern (concat "actypes::"
-						(symbol-name type))))))
+			       (documentation (symtable:actype-p type))))
 			    link-types)))
 		    type-and-args (hui:list-remove-text-properties type-and-args))
 	      (hui:link-create
@@ -508,7 +637,7 @@ See also documentation for `hui:link-possible-types'."
 ;;; ************************************************************************
 
 (defun hui:action (actype &optional prompt)
-  "Prompts for and returns an action to override action from ACTYPE."
+  "Prompt for and return an action to override action from ACTYPE."
   (and actype
        (let* ((act) (act-str)
 	      (params (actype:params actype))
@@ -565,19 +694,17 @@ See also documentation for `hui:link-possible-types'."
 
 (defun hui:actype (&optional default-actype prompt)
   "Using optional DEFAULT-ACTYPE, PROMPTs for a button action type.
-DEFAULT-ACTYPE may be a valid symbol or symbol-name."
-  (and default-actype (symbolp default-actype)
-       (progn
-	 (setq default-actype (symbol-name default-actype))
-	 (if (string-match "actypes::" default-actype)
-	     (setq default-actype (substring default-actype (match-end 0))))))
+DEFAULT-ACTYPE may be a valid symbol or `symbol-name'."
+  (when (and default-actype (symbolp default-actype))
+    (setq default-actype (symbol-name default-actype)
+	  default-actype (actype:def-symbol default-actype)
+	  default-actype (when default-actype (symbol-name default-actype))))
   (if (or (null default-actype) (stringp default-actype))
-      (intern-soft
-       (concat "actypes::"
-	       (hargs:read-match (or prompt "Button's action type: ")
-				(mapcar 'list (htype:names 'actypes))
-				nil t default-actype 'actype)))
-    (hypb:error "(actype): Invalid default action type received.")))
+      (actype:elisp-symbol
+       (hargs:read-match (or prompt "Button's action type: ")
+			 (mapcar 'list (htype:names 'actypes))
+			 nil t default-actype 'actype))
+    (hypb:error "(actype): Invalid default action type received")))
 
 (defun hui:buf-writable-err (but-buf func-name)
   "If BUT-BUF is read-only, signal an error from FUNC-NAME."
@@ -588,7 +715,7 @@ DEFAULT-ACTYPE may be a valid symbol or symbol-name."
     ;; (if unwritable
     ;;     Commented error out since some people want to be able to create
     ;;     buttons within files which they have purposely marked read-only.
-    ;;     (setq err 
+    ;;     (setq err
     ;;	     (format "(ebut-modify): Hyperbole lacks permission to write to '%s'."
     ;;		     (file-name-nondirectory buffer-file-name))))
     (if buffer-read-only
@@ -613,7 +740,7 @@ DEFAULT-ACTYPE may be a valid symbol or symbol-name."
 			    (if (and (not (string-match "mail\\*" b))
 				     (not (string-match "\\*post-news\\*" b))
 				     (string-match "\\`[* ]" b))
-				nil 
+				nil
 			      (cons b nil))))
 			(buffer-list)))
 		 nil t (buffer-name) 'buffer))
@@ -635,10 +762,10 @@ within."
 		((and (stringp key-src)
 		      (setq buf (find-file-noselect key-src)))
 		 (setq ebut (ebut:get but-key buf)))
-		(t (hypb:error "(ebut-delete): Invalid key-src: '%s'." key-src)))
+		(t (hypb:error "(ebut-delete): Invalid key-src: '%s'" key-src)))
 	  (if ebut
 	      (ebut:delete ebut)
-	    (hypb:error "(ebut-delete): No valid %s button in %s."
+	    (hypb:error "(ebut-delete): No valid %s button in %s"
 		   (ebut:key-to-label but-key) buf))
 	  )
 	(progn (set-buffer buf)
@@ -649,16 +776,15 @@ within."
 		 (hui:ebut-unmark but-key key-src))
 	       (if (hmail:reader-p) (hmail:msg-narrow))
 	       )
-      (hypb:error "(ebut-delete): You may not delete buttons from this buffer."))))
+      (hypb:error "(ebut-delete): You may not delete buttons from this buffer"))))
 
 (defun hui:ebut-delimit (start end instance-str)
-  (hypb:error "(hui:ebut-delimit): Obsolete, use ebut:delimit instead."))
+  (hypb:error "(hui:ebut-delimit): Obsolete, use ebut:delimit instead"))
 
 (defun hui:ebut-message (but-modify-flag)
   (let ((actype (symbol-name (hattr:get 'hbut:current 'actype)))
 	(args (hattr:get 'hbut:current 'args)))
-    (if (string-match "\\`actypes::" actype)
-	(setq actype (intern (substring actype (match-end 0)))))
+    (setq actype (actype:def-symbol actype))
     (message "%s%s%s %s %S"
 	     ebut:start
 	     (hbut:key-to-label (hattr:get 'hbut:current 'lbl-key))
@@ -714,16 +840,16 @@ All args are optional, the current button and buffer file are the defaults."
 		     (or cur-p (save-buffer)))))))))
 
 (defun hui:file-find (file-name)
-  "If FILE-NAME is readable, finds it, else signals an error."
+  "If FILE-NAME is readable, find it, else signal an error."
   (if (and (stringp file-name) (file-readable-p file-name))
       (find-file file-name)
-    (hypb:error "(file-find): \"%s\" does not exist or is not readable."
+    (hypb:error "(file-find): \"%s\" does not exist or is not readable"
 	   file-name)))
 
 (defun hui:hbut-term-highlight (start end)
   "For terminals only: Emphasize a button spanning from START to END."
-  (save-restriction
-    (save-excursion
+  (save-excursion
+    (save-restriction
       (goto-char start)
       (narrow-to-region (point-min) start)
       (sit-for 0)
@@ -737,8 +863,8 @@ All args are optional, the current button and buffer file are the defaults."
 
 (defun hui:hbut-term-unhighlight (start end)
   "For terminals only: Remove any emphasis from hyper-button at START to END."
-  (save-restriction
-    (save-excursion
+  (save-excursion
+    (save-restriction
       (goto-char start)
       (narrow-to-region (point-min) start)
       (sit-for 0)
@@ -809,23 +935,34 @@ Optional NO-SORT means display in decreasing priority order (natural order)."
 		   doc-list)))))
 
 (defun hui:htype-help-current-window (htype-sym &optional no-sort)
-  "Displays in the current window, documentation for types from HTYPE-SYM which match to a regexp.
+  "Display in the current window, documentation for types from HTYPE-SYM which match to a regexp.
 Optional NO-SORT means display in decreasing priority order (natural order)."
   (let ((display-buffer-alist
 	 '(("\\`*Help" . ((lambda (buf _alist) (switch-to-buffer buf)))))))
     (hui:htype-help htype-sym no-sort)))
 
+(defun hui:ibut-message (but-modify-flag)
+  (let ((actype (symbol-name (hattr:get 'hbut:current 'actype)))
+	(args (hattr:get 'hbut:current 'args)))
+    (setq actype (actype:def-symbol actype))
+    (message "%s%s%s %s %S"
+	     ibut:label-start
+	     (hbut:key-to-label (hattr:get 'hbut:current 'lbl-key))
+	     ibut:label-end
+	     (if but-modify-flag "now executes" "executes")
+	     (cons actype args))))
+
 (defun hui:key-dir (but-buf)
-  "Returns button key src directory based on BUT-BUF, a buffer."
+  "Return button key src directory based on BUT-BUF, a buffer."
   (if (bufferp but-buf)
       (let ((file (buffer-file-name but-buf)))
 	(if file
 	    (file-name-directory (hpath:symlink-referent file))
 	  (buffer-local-value 'default-directory but-buf)))
-    (hypb:error "(hui:key-dir): '%s' is not a valid buffer.")))
+    (hypb:error "(hui:key-dir): '%s' is not a valid buffer")))
 
 (defun hui:key-src (but-buf)
-  "Returns button key src location based on BUT-BUF, a buffer.
+  "Return button key src location based on BUT-BUF, a buffer.
 This is BUT-BUF when button data is stored in the buffer and the
 button's source file name when the button data is stored externally."
   (with-current-buffer but-buf
@@ -834,26 +971,23 @@ button's source file name when the button data is stored externally."
 	  (t but-buf))))
 
 (defun hui:link-create (modify but-window lbl-key but-loc but-dir type-and-args)
-  "Creates or modifies a new Hyperbole link button.
+  "Create or modify a new Hyperbole explicit link button.
 If MODIFY is non-nil, modifies button at point in BUT-WINDOW,
 otherwise, prompts for button label and creates a button.
 LBL-KEY is internal form of button label.  BUT-LOC is file or buffer
 in which to create button.  BUT-DIR is directory of BUT-LOC.
 TYPE-AND-ARGS is the action type for the button followed by any
-arguments it requires.  Any text properties are removed from string arguments." 
+arguments it requires.  Any text properties are removed from string arguments."
   (hattr:set 'hbut:current 'loc but-loc)
   (hattr:set 'hbut:current 'dir but-dir)
-  (hattr:set 'hbut:current 'actype (intern-soft
-				     (concat "actypes::"
-					     (symbol-name
-					       (car type-and-args)))))
+  (hattr:set 'hbut:current 'actype (actype:elisp-symbol (car type-and-args)))
   (hattr:set 'hbut:current 'args (cdr type-and-args))
   (select-window but-window)
   (let ((label (ebut:key-to-label lbl-key)))
     (ebut:operate label (if modify label))))
 
 (defun hui:link-possible-types ()
-  "Returns list of possible link types for a Hyperbole button link to point.
+  "Return list of possible link action types during editing of a Hyperbole button.
 Each list element is a list of the link type and any arguments it requires.
 
 The link types considered are fixed; this function must be changed to alter
@@ -862,7 +996,9 @@ possible types.
 
 Referent Context         Possible Link Type Returned
 ----------------------------------------------------
+Global Button            link-to-gbut
 Explicit Button          link-to-ebut
+Implicit Button          link-to-ibut
 Info Index Item          link-to-Info-index-item
 Info Node                link-to-Info-node
 Mail Reader Message      link-to-mail
@@ -877,8 +1013,12 @@ Buffer without File      link-to-buffer-tmp"
 
   (let (val)
     (delq nil
-	  (list (if (ebut:at-p)
-		    (list 'link-to-ebut buffer-file-name (ebut:label-p)))
+	  (list (cond ((eq (current-buffer) (get-file-buffer gbut:file))
+		       (list 'link-to-gbut (hbut:label-p)))
+		      ((ebut:at-p)
+		       (list 'link-to-ebut (ebut:label-p)))
+		      ((setq val (ibut:at-p t))
+		       (list 'link-to-ibut val)))
 		(cond ((eq major-mode 'Info-mode)
 		       (if (and Info-current-node
 				(member Info-current-node
@@ -938,7 +1078,7 @@ Buffer without File      link-to-buffer-tmp"
 		))))
 
 (defun hui:list-remove-text-properties (lst)
-  "Returns LST, a list, with text properties removed from any string elements."
+  "Return LST, a list, with text properties removed from any string elements."
   (mapcar (lambda (elt) (if (stringp elt) (substring-no-properties elt) elt))
 	  lst))
 
