@@ -1,11 +1,11 @@
 ;;; hversion.el --- GNU Hyperbole version and system information setup
 ;;
 ;; Author:       Bob Weiner
-;; Maintainer:   Bob Weiner and Mats Lidell
+;; Maintainer:   Bob Weiner, Mats Lidell
 ;;
 ;; Orig-Date:     1-Jan-94
 ;;
-;; Copyright (C) 1994-2019  Free Software Foundation, Inc.
+;; Copyright (C) 1994-2020  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -23,7 +23,7 @@
 ;;; Public variables
 ;;; ************************************************************************
 
-(defconst hyperb:version "7.0.3" "GNU Hyperbole revision number.")
+(defconst hyperb:version "7.0.8" "GNU Hyperbole revision number.")
 
 ;;;###autoload
 (defvar hyperb:microsoft-os-p
@@ -39,7 +39,7 @@ Use `hyperb:wsl-os-p' to test if running under WSL.")
 ;;;###autoload
 (defvar hyperb:mouse-buttons
   (if (or (and hyperb:microsoft-os-p (not (memq window-system '(w32 w64 x))))
-	  (and hyperb:emacs-p (memq window-system '(ns dps))))
+	  (memq window-system '(ns dps)))
       2 3)
   "Number of live buttons available on the mouse.
 Override this if the system-computed default is incorrect for your specific mouse.")
@@ -122,7 +122,7 @@ the pathname."
 		     file)))))
 
 (defun hyperb:window-sys-term (&optional frame)
-  "Returns the first part of the term-type if running under a window system, else nil.
+  "Return the first part of the term-type if running under a window system, else nil.
 Where a part in the term-type is delimited by a `-' or  an `_'."
   (unless frame (setq frame (selected-frame)))
   (let* ((display-type (if (fboundp 'device-type) (device-type) window-system))
@@ -133,9 +133,7 @@ Where a part in the term-type is delimited by a `-' or  an `_'."
 			  ;; then there is a window system to support.
 			  (display-mouse-p))
 		      ;; X11, macOS, NEXTSTEP (DPS), or OS/2 Presentation Manager (PM)
-		      (cond (hyperb:emacs-p "emacs")
-			    ((featurep 'xemacs)  "xemacs")
-			    (t                "xterm")))
+		      "emacs")
 		     ((or (featurep 'eterm-fns)
 			  (equal (getenv "TERM") "NeXT")
 			  (equal (getenv "TERM") "eterm"))
@@ -147,7 +145,7 @@ Where a part in the term-type is delimited by a `-' or  an `_'."
     term))
 
 (defun hyperb:window-system (&optional frame)
-  "Returns the string name for window system or term type under which the selected frame is running.
+  "Return the string name for window system or term type under which the selected FRAME is running.
 If nil after system initialization, no window system or mouse support is available."
   (unless frame (setq frame (selected-frame)))
   (frame-parameter frame 'hyperb:window-system))
@@ -157,7 +155,7 @@ If nil after system initialization, no window system or mouse support is availab
 ;; each frame.
 (mapc #'hyperb:window-sys-term (frame-list))
 ;; Ensure this next hook is appended so that if follows the hook that
-;; selects the new frame. 
+;; selects the new frame.
 (add-hook 'after-make-frame-functions #'hyperb:window-sys-term t)
 
 ;;; ************************************************************************
