@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:     6-Oct-91 at 03:42:38
 ;;
-;; Copyright (C) 1991-2016  Free Software Foundation, Inc.
+;; Copyright (C) 1991-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -27,7 +27,11 @@
 This should end with a space.")
 
 (defcustom hypb:rgrep-command
-  (format "%sgrep -insIHr" (if (executable-find "zgrep") "z" ""))
+  ;; Only the FreeBSD version of zgrep supports all of the grep
+  ;; options that Hyperbole needs: -r, --include, and --exclude
+  (format "%sgrep -insIHr" (if (and (executable-find "zgrep")
+                                    (string-match-p "bsd" (shell-command-to-string "zgrep --version | head -1")))
+                               "z" ""))
   "*Grep command string and initial arguments to send to `hypb:rgrep' command.
 It must end with a space."
   :type 'string
@@ -38,7 +42,7 @@ It must end with a space."
 ;;; ************************************************************************
 
 (defun hypb:call-process-p (program &optional infile predicate &rest args)
-  "Calls an external PROGRAM with INFILE for input.
+  "Call an external PROGRAM with INFILE for input.
 If PREDICATE is given, it is evaluated in a buffer with the PROGRAM's
 output and the result returned.  If PREDICATE is nil, returns t iff
 program has no output or just a 0-valued output.
@@ -49,7 +53,7 @@ Rest of ARGS are passed as arguments to PROGRAM."
       (setq buffer-read-only nil)
       (erase-buffer)
       (apply 'call-process program infile buf nil args)
-      (setq found 
+      (setq found
 	    (if predicate
 		(eval predicate)
 	      (or (= (point-max) 1) ;; No output, consider cmd a success.
@@ -69,7 +73,7 @@ Rest of ARGS are passed as arguments to PROGRAM."
     c))
 
 (defun hypb:chmod (op octal-permissions file)
-  "Uses OP and OCTAL-PERMISSIONS integer to set FILE permissions.
+  "Use OP and OCTAL-PERMISSIONS integer to set FILE permissions.
 OP may be +, -, xor, or default =."
   (let ((func (cond ((eq op '+)   #'logior)
 		    ((eq op '-)   (lambda (p1 p2) (logand (lognot p1) p2)))
@@ -79,7 +83,7 @@ OP may be +, -, xor, or default =."
 				  (file-modes file)))))
 
 (defun hypb:cmd-key-string (cmd-sym &optional keymap)
-  "Returns a single pretty printed key sequence string bound to CMD-SYM.
+  "Return a single pretty printed key sequence string bound to CMD-SYM.
 Global keymap is used unless optional KEYMAP is given."
   (if (and cmd-sym (symbolp cmd-sym) (fboundp cmd-sym))
   (let* ((get-keys (lambda (cmd-sym keymap)
@@ -92,7 +96,7 @@ Global keymap is used unless optional KEYMAP is given."
 			" " (symbol-name cmd-sym) " RET")
 	      keys)
 	    "}"))
-  (error "(hypb:cmd-key-string): Invalid cmd-sym arg: %s." cmd-sym)))
+  (error "(hypb:cmd-key-string): Invalid cmd-sym arg: %s" cmd-sym)))
 
 ;;;###autoload
 (defun hypb:configuration (&optional out-buf)
@@ -144,7 +148,7 @@ Global keymap is used unless optional KEYMAP is given."
       (untabify start (point)))))
 
 (defun hypb:debug ()
-  "Loads Hyperbole hbut.el source file and sets debugging traceback flag."
+  "Load Hyperbole hbut.el source file and set debugging traceback flag."
   (interactive)
   (or (featurep 'hinit) (load "hyperbole"))
   (or (and (featurep 'hbut)
@@ -182,7 +186,7 @@ Global keymap is used unless optional KEYMAP is given."
       string)))
 
 (defun hypb:domain-name ()
-  "Returns current Internet domain name with '@' prepended or nil if none."
+  "Return current Internet domain name with '@' prepended or nil if none."
   (let* ((dname-cmd (or (file-exists-p "/usr/bin/domainname")
 			(file-exists-p "/bin/domainname")))
 	 (dname (or (and (boundp 'message-user-fqdn) (stringp message-user-fqdn)
@@ -191,7 +195,7 @@ Global keymap is used unless optional KEYMAP is given."
 		    (getenv "DOMAINNAME")
 		    (if dname-cmd
 			(hypb:call-process-p
-			 "domainname" nil 
+			 "domainname" nil
 			 '(substring (buffer-string) 0 -1)))))
 	 host-and-domain)
     (if (or (and dname (string-match "\\." dname))
@@ -215,12 +219,15 @@ Global keymap is used unless optional KEYMAP is given."
 
 (defun hypb:emacs-byte-code-p (obj)
   "Return non-nil iff OBJ is an Emacs byte compiled object."
-  (or (and (fboundp 'compiled-function-p) (compiled-function-p obj))
-      (and (fboundp 'byte-code-function-p) (byte-code-function-p obj))))
+  (or (and (fboundp 'byte-code-function-p) (byte-code-function-p obj))
+      (and (fboundp 'compiled-function-p) (compiled-function-p obj))))
 
 (defun hypb:error (&rest args)
   "Signals an error typically to be caught by `hyperbole'."
-  (let ((msg (if (< (length args) 2) (car args) (apply 'format args))))
+  (let ((msg (if (< (length args) 2)
+		 (car args)
+	       (apply 'format (cons (car args)
+				    (mapcar #'hypb:format-quote (cdr args)))))))
     (put 'error 'error-message msg)
     (error msg)))
 
@@ -233,32 +240,23 @@ FILE is temporarily read into a buffer to determine the major mode if necessary.
       (unless (or existing-flag (null buf))
 	(kill-buffer buf)))))
 
-(defun hypb:format-quote (string)
-  "Replace all single % with %% in STRING so a call to `format' or `message' ignores them."
-  (if (stringp string)
+(defun hypb:format-quote (arg)
+  "Replace all single % with %% in any string ARG so that a call to `format' or `message' ignore them.
+Return either the modified string or the original ARG."
+  (if (stringp arg)
       (replace-regexp-in-string
        "@@@" "%%" (replace-regexp-in-string
-		   "%" "%%" (replace-regexp-in-string "%%" "@@@" string nil t)
+		   "%" "%%" (replace-regexp-in-string "%%" "@@@" arg nil t)
 		   nil t)
-       nil t)))
-
-;;;###autoload
-(defun hypb:functionp (obj)
-"Returns t if OBJ is a function, nil otherwise."
-  (cond
-    ((symbolp obj) (fboundp obj))
-    ((subrp obj))
-    ((hypb:emacs-byte-code-p obj))
-    ((consp obj)
-     (if (eq (car obj) 'lambda) (listp (car (cdr obj)))))
-    (t nil)))
+       nil t)
+    arg))
 
 (defun hypb:function-copy (func-symbol)
-  "Copies FUNC-SYMBOL's body for overloading.  Returns copy of body."
+  "Copy FUNC-SYMBOL's body for overloading.  Return copy of body."
   (if (fboundp func-symbol)
       (let ((func (hypb:indirect-function func-symbol)))
 	(cond ((listp func) (copy-sequence func))
-	      ((subrp func) (error "(hypb:function-copy): `%s' is a primitive; can't copy body."
+	      ((subrp func) (error "(hypb:function-copy): `%s' is a primitive; can't copy body"
 				   func-symbol))
 	      ((and (hypb:emacs-byte-code-p func) (fboundp 'make-byte-code))
 	       (if (not (fboundp 'compiled-function-arglist))
@@ -277,7 +275,7 @@ FILE is temporarily read into a buffer to determine the major mode if necessary.
 		       (setq new-code (nconc new-code (list (nth 1 spec)))))
 		   (apply 'make-byte-code new-code))))
 	      (t (error "(hypb:function-copy): Can't copy function body: %s" func))))
-    (error "(hypb:function-copy): `%s' symbol is not bound to a function."
+    (error "(hypb:function-copy): `%s' symbol is not bound to a function"
 	   func-symbol)))
 
 (defun hypb:function-overload (func-sym prepend &rest new-forms)
@@ -307,7 +305,7 @@ FILE is temporarily read into a buffer to determine the major mode if necessary.
 		(append old-func-call new-forms)))))))
 
 (defun hypb:function-symbol-replace (func-sym sym-to-replace replace-with-sym)
-  "Replaces in body of FUNC-SYM SYM-TO-REPLACE with REPLACE-WITH-SYM.
+  "Replace in body of FUNC-SYM SYM-TO-REPLACE with REPLACE-WITH-SYM.
 FUNC-SYM may be a function symbol or its body.  All occurrences within lists
 are replaced.  Returns body of modified FUNC-SYM."
   (let ((body (hypb:indirect-function func-sym))
@@ -366,7 +364,7 @@ If MARKER is invalid signal an error."
 	     (switch-to-buffer buffer)))))
 
 (defun hypb:help-buf-name (&optional suffix)
-  "Returns a Hyperbole help buffer name for current buffer.
+  "Return a Hyperbole help buffer name for current buffer.
 With optional SUFFIX string, uses it rather than buffer name."
   (let ((bn (or suffix (buffer-name))))
     (if (string-match (regexp-quote hypb:help-buf-prefix) bn)
@@ -423,7 +421,7 @@ copied, otherwise, it is omitted."
 	
 ;;;###autoload
 (defun hypb:locate (search-string &optional filter arg)
-  "Find file name matches anywhere, calling the value of `locate-command', and putting results in the `*Locate*' buffer.
+  "Find file name match anywhere, calling the value of `locate-command', and putting results in the `*Locate*' buffer.
 Pass it SEARCH-STRING as argument.  Interactively, prompt for SEARCH-STRING.
 With prefix arg ARG, prompt for the exact shell command to run instead.
 
@@ -453,33 +451,23 @@ then `locate-post-command-hook'."
 		     current-prefix-arg))
   (locate search-string filter arg))
 
-(if (or (featurep 'xemacs) hyperb:emacs-p)
-    (defalias 'hypb:mark 'mark)
-  (defun hypb:mark (inactive-p)
-    "Return this buffer's mark value as integer, or nil if no mark.
-INACTIVE-P non-nil means return value of mark even if region is not active
-under Emacs version 19.
-If you are using this in an editing command, you are most likely making
-a mistake; see the documentation of `set-mark'."
-    (mark)))
+(defalias 'hypb:mark #'mark)
 
-(if (featurep 'xemacs)
-    (defalias 'hypb:mark-marker 'mark-marker)
-  (defun hypb:mark-marker (inactive-p)
-    "Return this buffer's mark as a marker object, or nil if no mark.
+(defun hypb:mark-marker (inactive-p)
+  "Return this buffer's mark as a marker object, or nil if no mark.
 INACTIVE-P is unused, it is for compatibility with XEmacs' version of
-mark-marker."
-    (mark-marker)))
+`mark-marker'."
+  (mark-marker))
 
 ;;;###autoload
 (defun hypb:map-plist (func plist)
-  "Returns result of applying FUNC of two args, key and value, to key-value pairs in PLIST, a property list."
+  "Return result of applying FUNC of two args, key and value, to key-value pairs in PLIST, a property list."
   (cl-loop for (k v) on plist by #'cddr
 	   collect (funcall func k v) into result
 	   finally return result))
 
 (defun hypb:map-sublists (func list)
-  "Applies FUNC to every atom found at any level of LIST.
+  "Apply FUNC to every atom found at any level of LIST.
 FUNC must take two arguments, an atom and a list in which the atom is found.
 Returns values from applications of FUNC as a list with the same
 structure as LIST.  FUNC is therefore normally used just for its side-effects."
@@ -490,10 +478,10 @@ structure as LIST.  FUNC is therefore normally used just for its side-effects."
 	  list))
 
 (defun hypb:map-vector (func object)
-  "Returns list of results of application of FUNC to each element of OBJECT.
-OBJECT should be a vector or byte-code object."
+  "Return list of results of application of FUNC to each element of OBJECT.
+OBJECT should be a vector or `byte-code' object."
   (if (not (or (vectorp object) (hypb:emacs-byte-code-p object)))
-      (error "(hypb:map-vector): Second argument must be a vector or byte-code object."))
+      (error "(hypb:map-vector): Second argument must be a vector or byte-code object"))
   (let ((end (length object))
 	(i 0)
 	(result))
@@ -517,7 +505,7 @@ WINDOW pixelwise."
    nil nil window-resize-pixelwise))
 
 (defun hypb:replace-match-string (regexp str newtext &optional literal)
-  "Replaces all matches for REGEXP in STR with NEWTEXT string and returns the result.
+  "Replace all matches for REGEXP in STR with NEWTEXT string and return the result.
 Optional LITERAL non-nil means do a literal replacement.
 Otherwise treat \\ in NEWTEXT string as special:
   \\& means substitute original matched text,
@@ -527,7 +515,7 @@ NEWTEXT may instead be a function of one argument (the string to replace in)
 that returns a replacement string."
   (unless (stringp str)
     (error "(hypb:replace-match-string): 2nd arg must be a string: %s" str))
-  (unless (or (stringp newtext) (hypb:functionp newtext))
+  (unless (or (stringp newtext) (functionp newtext))
     (error "(hypb:replace-match-string): 3rd arg must be a string or function: %s"
 	   newtext))
   (let ((rtn-str "")
@@ -541,7 +529,7 @@ that returns a replacement string."
 	    (concat
 	      rtn-str
 	      (substring str prev-start match)
-	      (cond ((hypb:functionp newtext)
+	      (cond ((functionp newtext)
 		     (hypb:replace-match-string
 		      regexp (substring str match start)
 		      (funcall newtext str) literal))
@@ -572,7 +560,7 @@ that returns a replacement string."
     (concat rtn-str (substring str start))))
 
 (defun hypb:return-process-output (program &optional infile &rest args)
-  "Returns as a string the output from external PROGRAM with INFILE for input.
+  "Return as a string the output from external PROGRAM with INFILE for input.
 Rest of ARGS are passed as arguments to PROGRAM.
 Removes any trailing newline at the end of the output."
   (let ((buf (get-buffer-create "*test-output*"))
@@ -589,7 +577,7 @@ Removes any trailing newline at the end of the output."
     output))
 
 (defun hypb:remove-lines (regexp)
- "Remove lines containing matches for REGEXP within the active region or to the end of buffer."
+ "Remove lines containing match for REGEXP within the active region or to the end of buffer."
     (interactive "sRemove lines with match for regexp: ")
     (flush-lines regexp nil nil t))
 
@@ -630,7 +618,7 @@ If in an Emacs Lisp mode buffer and no PREFIX-ARG is given, limit search to only
     (grep grep-cmd)))
 
 (defun hypb:save-lines (regexp)
- "Save only lines containing matches for REGEXP within the active region or to the end of buffer."
+ "Save only lines containing match for REGEXP within the active region or to the end of buffer."
     (interactive "sSave lines with match for regexp: ")
     (keep-lines regexp nil nil t))
 
@@ -649,7 +637,7 @@ The value returned is the value of the last form in BODY."
     (error "(hypb:select-window-frame): Argument must be a live window, not '%s'" window)))
 
 (defun hypb:supercite-p ()
-  "Returns non-nil iff the Emacs add-on supercite package is in use."
+  "Return non-nil iff the Emacs add-on supercite package is in use."
   (let (hook-val)
     (if (memq t (mapcar
 		 (lambda (hook-var)
@@ -667,7 +655,7 @@ The value returned is the value of the last form in BODY."
 This determines whether to search inside invisible text or not.
 Toggles the variable ‘isearch-invisible’ between values
 nil and a non-nil value of the option ‘search-invisible’
-(or ‘open’ if ‘search-invisible’ is nil).
+\(or ‘open’ if ‘search-invisible’ is nil).
 
 With optional prefix ARG > 0, turn on searching invisible text.
 If ARG <= 0, turn search only visible text."
@@ -688,7 +676,7 @@ If ARG <= 0, turn search only visible text."
     (user-login-name)))
 
 (defun hypb:window-list (&optional minibuffer-flag)
-  "Returns a list of Lisp window objects for all Emacs windows in selected frame.
+  "Return a list of Lisp window objects for all Emacs windows in selected frame.
 Optional first arg MINIBUFFER-FLAG t means include the minibuffer window
 in the list, even if it is not active.  If MINIBUFFER-FLAG is neither t
 nor nil it means to not count the minibuffer window even if it is active."
@@ -699,18 +687,13 @@ nor nil it means to not count the minibuffer window even if it is active."
 ;;; ************************************************************************
 
 (defvar hypb:home-page "https://www.gnu.org/software/hyperbole/"
-  "The web home page for Hyperbole")
+  "The web home page for Hyperbole.")
 
 (defvar hypb:hyperbole-banner-keymap
   (let ((map (make-sparse-keymap)))
-    (cond (hyperb:emacs-p
-	   (define-key map [mouse-1]  'hypb:browse-home-page)
-	   (define-key map [mouse-2]  'hypb:browse-home-page)
-	   (define-key map "\C-m"     'hypb:browse-home-page))
-	  ((featurep 'xemacs)
-	   (define-key map 'button1  'hypb:browse-home-page)
-	   (define-key map 'button2  'hypb:browse-home-page)
-	   (define-key map '(return) 'hypb:browse-home-page)))
+    (define-key map [mouse-1]  'hypb:browse-home-page)
+    (define-key map [mouse-2]  'hypb:browse-home-page)
+    (define-key map "\C-m"     'hypb:browse-home-page)
     map)
   "Keymap used when on the Hyperbole banner glyph.")
 
@@ -721,9 +704,7 @@ Without file, the banner is prepended to the current buffer."
   (if file
       ;; A stub for this function is defined in hversion.el when not running in InfoDock.
       (id-browse-file file))
-  (if hyperb:emacs-p
-      (hypb:display-file-with-logo-emacs file)
-    (hypb:display-file-with-logo-xemacs file))
+  (hypb:display-file-with-logo-emacs file)
   (goto-char (point-min))
   (skip-syntax-forward "-")
   (set-window-start (selected-window) 1)
@@ -785,37 +766,6 @@ Without file, the banner is prepended to the current buffer."
 	(button-put button 'face 'default)
 	(button-put button 'keymap hypb:hyperbole-banner-keymap)))))
 
-(defun hypb:display-file-with-logo-xemacs (&optional file)
-  "Display an optional text FILE with the Hyperbole banner prepended.
-Without file, the banner is prepended to the current buffer."
-  (let ((hyperbole-banner-path (expand-file-name "hyperbole-banner.png" hyperb:dir)))
-    (if (not (file-readable-p hyperbole-banner-path))
-	(setq hyperbole-banner-path (if (fboundp 'locate-data-file)
-					(locate-data-file "hyperbole-banner.png")
-				      (expand-file-name "hyperbole-banner.png"
-							data-directory))))
-    (if (or (not (fboundp 'make-glyph))
-	    (let ((extent (next-extent (current-buffer))))
-	      (and extent (extent-property extent 'hyperbole-banner)))
-	    (not hyperbole-banner-path)
-	    (not (file-readable-p hyperbole-banner-path)))
-	;; Either image support is unavailable, the file cannot be read
-	;; or the image has already been inserted, so don't reinsert it.
-	nil
-      (let ((hyperbole-banner (make-glyph hyperbole-banner-path))
-	     (buffer-read-only)
-	     extent)
-	(goto-char (point-min))
-	(insert "\n")
-	(indent-to (startup-center-spaces hyperbole-banner))
-	(insert "\n\n")
-	(setq extent (make-extent (- (point) 3) (- (point) 2)))
-	(set-extent-end-glyph extent hyperbole-banner)
-	(set-extent-property extent 'hyperbole-banner t)
-	(set-extent-property extent 'help-echo
-			     (concat "Click to visit " hypb:home-page))
-	(set-extent-property extent 'keymap hypb:hyperbole-banner-keymap)))))
-
 (defun hypb:locate-pathnames ()
   (save-excursion
     (goto-char (point-min))
@@ -824,7 +774,7 @@ Without file, the banner is prepended to the current buffer."
 			      (buffer-substring-no-properties (point) (point-max)))))
 
 (defun hypb:oct-to-int (oct-num)
-  "Returns octal integer OCTAL-NUM converted to a decimal integer."
+  "Return octal integer OCT-NUM converted to a decimal integer."
   (let ((oct-str (int-to-string oct-num))
 	(dec-num 0))
     (and (string-match "[^0-7]" oct-str)
@@ -840,7 +790,7 @@ Without file, the banner is prepended to the current buffer."
 ;;; Private variables
 ;;; ************************************************************************
 
-(if hyperb:emacs-p (define-button-type 'hyperbole-banner))
+(define-button-type 'hyperbole-banner)
 
 (provide 'hypb)
 
