@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    28-Oct-94 at 10:59:44
 ;;
-;; Copyright (C) 1994-2016  Free Software Foundation, Inc.
+;; Copyright (C) 1994-2019  Free Software Foundation, Inc.
 ;; See the "HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -35,9 +35,10 @@
     ["Display-Prior-Matches" (id-tool-invoke 'hyrolo-display-matches) t]
     ["Edit-Entry"        (id-tool-invoke 'hyrolo-edit) t]
     ["Edit-Rolo"         (id-tool-invoke
-			  '(progn (require 'hyrolo)
-				  (find-file (car hyrolo-file-list))
-				  (setq buffer-read-only nil)))
+			  '(lambda ()
+			     (require 'hyrolo)
+			     (find-file (car hyrolo-file-list))
+			     (setq buffer-read-only nil)))
      t]
     ["Insert-Entry-at-Point" (id-tool-invoke 'hyrolo-yank) t]
     ["Mail-to-Address"   (id-tool-invoke 'hyrolo-mail-to) t]
@@ -112,21 +113,15 @@
 ;;; Public functions
 ;;; ************************************************************************
 
-;;; This definition is used only by XEmacs and Emacs.
+;;; This definition is used only by Emacs.
 (defun hyrolo-menubar-menu ()
   "Add a HyRolo menu to the rolo match buffer menubar."
   (cond ((fboundp 'popup-mode-menu)
 	 (setq mode-popup-menu id-popup-hyrolo-menu))
-	((featurep 'xemacs)
-	 (define-key hyrolo-mode-map 'button3 'hyrolo-popup-menu))
-	(t ;; hyperb:emacs-p
+	(t
 	 (define-key hyrolo-mode-map [C-down-mouse-3] 'hyrolo-popup-menu)
 	 (define-key hyrolo-mode-map [C-mouse-3] nil)))
-  (unless (cond (hyperb:emacs-p
-		 (global-key-binding [menu-bar Rolo]))
-		((boundp 'current-menubar)
-		 (car (find-menu-item current-menubar '("Rolo")))))
-    (if (featurep 'xemacs) (set-buffer-menubar (copy-sequence current-menubar)))
+  (unless (global-key-binding [menu-bar Rolo])
     (easy-menu-define nil hyrolo-mode-map "Rolo Menubar Menu" id-popup-hyrolo-menu)
     ;; Force a menu-bar update.
     (force-mode-line-update)))
@@ -142,7 +137,7 @@
        ;; InfoDock under a window system
        (require 'id-menubars)
        (id-menubar-set 'hyrolo-mode 'id-menubar-hyrolo))
-      ((or hyperb:emacs-p (featurep 'xemacs))
+      (t
        ;; Emacs or XEmacs under a window system
        (add-hook 'hyrolo-mode-hook #'hyrolo-menubar-menu)))
 
