@@ -4,7 +4,7 @@
 ;;
 ;; Orig-Date:    28-Mar-94 at 11:22:09
 ;;
-;; Copyright (C) 1994-2016  Free Software Foundation, Inc.
+;; Copyright (C) 1994-2019  Free Software Foundation, Inc.
 ;; See the "../HY-COPY" file for license information.
 ;;
 ;; This file is part of GNU Hyperbole.
@@ -193,16 +193,10 @@
   "Add a Koutline menu to the menubar for each koutline buffer."
   (cond ((fboundp 'popup-mode-menu)
 	 (setq mode-popup-menu id-popup-kotl-menu))
-	((featurep 'xemacs)
-	 (define-key kotl-mode-map 'button3 'kotl-popup-menu))
-	(t ;; hyperb:emacs-p
+	(t
 	 (define-key kotl-mode-map [C-down-mouse-3] 'kotl-popup-menu)
 	 (define-key kotl-mode-map [C-mouse-3] nil)))
-  (unless (cond (hyperb:emacs-p
-		 (global-key-binding [menu-bar Koutline]))
-		((boundp 'current-menubar)
-		 (car (find-menu-item current-menubar '("Koutline")))))
-    (if (featurep 'xemacs) (set-buffer-menubar (copy-sequence current-menubar)))
+  (unless (global-key-binding [menu-bar Koutline])
     (easy-menu-define nil kotl-mode-map "Koutline Menubar Menu" id-popup-kotl-menu)
     ;; Force a menu-bar update.
     (force-mode-line-update)))
@@ -218,7 +212,7 @@
        ;; InfoDock under a window system
        (require 'id-menubars)
        (id-menubar-set 'kotl-mode 'id-menubar-kotl))
-      ((or hyperb:emacs-p (featurep 'xemacs))
+      (t
        ;; Emacs or XEmacs under a window system
        (add-hook 'kotl-mode-hook #'kotl-menubar-menu)))
 
